@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.15 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.16 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.15 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigComponents.php,v 1.16 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigComponents extends SyL_Config
@@ -66,12 +66,14 @@ class SyL_ConfigComponents extends SyL_Config
      */
     function parseXml()
     {
-        if (SYL_PROJECT_CACHE_DIR) {
+        if (SYL_CACHE) {
             // åѤ
-            $cache =& $this->getCacheObject(SYL_PROJECT_CACHE_DIR . 'components');
+            $key = implode('', $this->file_names);
+            $cache =& $this->getCache($key);
             if ($cache) {
+                // å夬Ǥʤäʥå奪֥Ȥ
                 parent::parseXml();
-                $cache->write($this->getCache());
+                $cache->write($this->config);
             }
         } else {
             // åѤʤ
