@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.17 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.18 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.17 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.18 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigFilters extends SyL_Config
@@ -155,7 +155,7 @@ class SyL_ConfigFilters extends SyL_Config
             // ̾ǧ
             $reg = isset($attribute['path']) ? str_replace('/', '\\/', $attribute['path']) : '(.*)';
             if (preg_match('/^' . $reg . '$/', $this->action_file)) {
-                $name = '__filter_' . $attribute['name'];
+                $name = $attribute['name'];
                 $this->config[$name]['type']      = 'filter';
                 $this->config[$name]['class']     = $attribute['class'];
                 $this->config[$name]['file']      = $attribute['file'];
