@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextJs.php,v 1.4 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextJs.php,v 1.5 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Request.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextJs.php,v 1.4 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextJs.php,v 1.5 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ContextJs extends SyL_Context
@@ -71,6 +71,27 @@ class SyL_ContextJs extends SyL_Context
         return $this->request;
     }
 
+    /**
+     * GETꥯȤȽꤹ
+     *
+     * @access public
+     * @return bool true: GETꥯȡfalse: GETꥯȰʳ
+     */
+    function isGet()
+    {
+        return (isset($_SERVER['REQUEST_METHOD']) && ($_SERVER['REQUEST_METHOD'] == 'GET'));
+    }
+
+    /**
+     * POSTꥯȤȽꤹ
+     *
+     * @access public
+     * @return bool true: POSTꥯȡfalse: POSTꥯȰʳ
+     */
+    function isPost()
+    {
+        return (isset($_SERVER['REQUEST_METHOD']) && ($_SERVER['REQUEST_METHOD'] == 'POST'));
+    }
 }
 
 ?>
