@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.9 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.10 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -46,7 +46,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.9 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.10 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ControllerCmd extends SyL_Controller
@@ -65,6 +65,29 @@ class SyL_ControllerCmd extends SyL_Controller
         $this->raiseEvent('initStream', $config_file);
     }
 
+    /**
+     * ¹
+     *
+     * @access protected
+     */
+    function loadStream()
+    {
+        $config_files = array();
+        // ץꥱե륿ե
+        $filter = SYL_APP_DIR . "/{$this->filter_file_name}";
+        if (file_exists($filter)) {
+            $config_files['filters'][] = $filter;
+        }
+        // Хե륿ե
+        $filter = SYL_PROJECT_CONFIG_DIR . "/{$this->filter_file_name}";
+        if (file_exists($filter)) {
+            $config_files['filters'][] = $filter;
+        }
+
+        // ٥ȼ¹
+        $this->raiseEvent('loadStream', $config_files);
+    }
+
     /**
      * ¹
      *
