@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.19 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.20 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.19 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.20 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorWeb extends SyL_Error
@@ -81,7 +81,7 @@ class SyL_ErrorWeb extends SyL_Error
                     foreach (file($error_file) as $line => $source) {
                         if (($line + 1) >= $start_line) {
                             if (($line + 1) == $error_line) {
-                                $tmp_lines[] = '<span style="color: #FF0000">Line ' . ($line + 1) . ': ' . $source . '</span>';
+                                $tmp_lines[] = '<span style="color: #FF0000">Line ' . ($line + 1) . ': ' . htmlspecialchars($source) . '</span>';
                             } else {
                                 $tmp_lines[] = 'Line ' . ($line + 1) . ': ' . htmlspecialchars($source);
                             }
