@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestFile.php,v 1.11 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestFile.php,v 1.12 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -42,7 +42,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RequestFile.php,v 1.11 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RequestFile.php,v 1.12 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RequestFile extends SyL_UtilProperty
@@ -163,7 +163,7 @@ class SyL_RequestFile extends SyL_UtilProperty
     function setUploadDir($upload_dir, $absolute=false)
     {
         $upload_dir = str_replace('..', '.', $upload_dir);
-        if (!preg_match('/^(.*)(\/|\\)$/', $upload_dir)) {
+        if (!preg_match('/^(.*)(\/|\\\\)$/', $upload_dir)) {
             $upload_dir .= '/';
         }
 
