@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.16 2007/06/05 13:08:24 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.17 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.16 2007/06/05 13:08:24 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.17 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterPathinfo extends SyL_Router
@@ -64,11 +64,11 @@ class SyL_RouterPathinfo extends SyL_Router
         $pathinfo = isset($_SERVER['PATH_INFO']) ? $_SERVER['PATH_INFO'] : '';
 
         if ($pathinfo == '') {
-            $this->action_name = '';
-            $this->action_file = '/' . $this->action_file_default;
+            $this->action_method = '';
+            $this->action_file   = '/' . $this->action_file_default;
         } else if (substr($pathinfo, -1) == '/') {
-            $this->action_name = '';
-            $this->action_file = $pathinfo . $this->action_file_default;
+            $this->action_method = '';
+            $this->action_file   = $pathinfo . $this->action_file_default;
         } else {
             // ĥȽ
             if ($this->url_ext && !preg_match('/^(.+)(' . preg_quote($this->url_ext) . ')$/', $pathinfo)) {
@@ -84,54 +84,56 @@ class SyL_RouterPathinfo extends SyL_Router
             }
 
             if ($pathinfo_dir != '/') {
-                $pathinfo_dir = $pathinfo_dir . '/';
+                $pathinfo_dir .= '/';
             }
 
+            // ƬʸѴ
+            $pathinfo_dir = implode('/', array_map('ucfirst', explode('/', $pathinfo_dir)));
+
             if (count($pathinfo_files) == 2) {
                 if (($this->action_delimiter == '.') && ($this->url_ext == ('.' . $pathinfo_files[1]))) {
-                    // ʤ
-                    $this->action_name = '';
-                    $this->action_file = $pathinfo_dir . $pathinfo_files[0] . $this->exe_ext;
+                    // ᥽åɤʤ
+                    $this->action_method = '';
+                    $this->action_file = $pathinfo_dir . ucfirst($pathinfo_files[0]) . $this->exe_ext;
                 } else {
+                    $this->action_method = ucfirst($pathinfo_files[0]);
                     if (preg_match('/^(.+)(' . preg_quote($this->url_ext) . '|' . preg_quote($this->exe_ext) . ')$/', $pathinfo_files[1], $matches)) {
-                        // 󤢤
-                        $this->action_name = $pathinfo_files[0];
-                        $this->action_file = $pathinfo_dir . $matches[1] . $this->exe_ext;
+                        // ᥽åɤ
+                        $this->action_file = $pathinfo_dir . ucfirst($matches[1]) . $this->exe_ext;
                     } else {
-                        // 󤢤
-                        $this->action_name = $pathinfo_files[0];
-                        $this->action_file = $pathinfo_dir . $pathinfo_files[1] . $this->exe_ext;
+                        // ᥽åɤ
+                        $this->action_file = $pathinfo_dir . ucfirst($pathinfo_files[1]) . $this->exe_ext;
                     }
                 }
             } else {
-                // ʤ
-                $this->action_name = '';
+                // ᥽åɤʤ
+                $this->action_method = '';
                 if (preg_match('/^(.+)(' . preg_quote($this->url_ext) . '|' . preg_quote($this->exe_ext) . ')$/', $pathinfo_files[1], $matches)) {
-                    $this->action_file = $pathinfo_dir . $matches[1] . $this->exe_ext;
+                    $this->action_file = $pathinfo_dir . ucfirst($matches[1]) . $this->exe_ext;
                 } else {
-                    $this->action_file = $pathinfo_dir . $pathinfo_files[1] . $this->exe_ext;
+                    $this->action_file = $pathinfo_dir . ucfirst($pathinfo_files[1]) . $this->exe_ext;
                 }
             }
         }
 
-        $action_name = null;
-        // ͤѥ᡼Υ
-        if (($action_name === null) && ((SYL_ROUTER_EXTRA_ACTION == '1') || (SYL_ROUTER_EXTRA_ACTION == '3'))) {
+        $action_method = null;
+        // ᥽åͤѥ᡼Υ
+        if (($action_method === null) && ((SYL_ROUTER_EXTRA_ACTION == '1') || (SYL_ROUTER_EXTRA_ACTION == '3'))) {
             $reg = '/^' . preg_quote(SYL_ACTION_KEY) . '_(.+)(_x|_y)?$/';
             foreach ($data->gets() as $name => $value) {
                 if (preg_match($reg, $name, $matches)) {
-                    $action_name = $matches[1];
+                    $action_method = $matches[1];
                     break;
                 }
             }
         }
         // ͤѥ᡼ͤ
-        if (($action_name === null) && ((SYL_ROUTER_EXTRA_ACTION == '2') || (SYL_ROUTER_EXTRA_ACTION == '3'))) {
-            $action_name = $data->get(SYL_ACTION_KEY);
+        if (($action_method === null) && ((SYL_ROUTER_EXTRA_ACTION == '2') || (SYL_ROUTER_EXTRA_ACTION == '3'))) {
+            $action_method = $data->get(SYL_ACTION_KEY);
         }
         // ֤
-        if ($action_name !== null) {
-            $this->action_name = $action_name;
+        if ($action_method !== null) {
+            $this->action_method = ucfirst($action_method);
         }
 
         // PATH_INFO
@@ -144,19 +146,18 @@ class SyL_RouterPathinfo extends SyL_Router
         // 饹ե
         $classname = implode('_', array_map('ucfirst', $pathinfo));
         if ($classname) {
-            $this->action_class = $classname . '_' . ucfirst(basename($this->action_file, $this->exe_ext));
+            $this->action_class = $classname . '_' . basename($this->action_file, $this->exe_ext);
         } else {
-            $this->action_class = ucfirst(basename($this->action_file, $this->exe_ext));
+            $this->action_class = basename($this->action_file, $this->exe_ext);
         }
 
 /*
 echo "pathinfo: " . $pathinfo . "<br>";
-echo "action_name: " . $this->action_name . "<br>";
+echo "action_method: " . $this->action_method . "<br>";
 echo "action_file: " . $this->action_file . "<br>";
 echo "class_name: " . $this->action_class . "<br>";
 exit;
 */
-
     }
 
 }
