@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ActionForm.php,v 1.2 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ActionForm.php,v 1.3 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_Form.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ActionForm.php,v 1.2 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ActionForm.php,v 1.3 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ActionForm extends SyL_Form
@@ -68,56 +68,82 @@ class SyL_ActionForm extends SyL_Form
      * 󥹥ȥ饯
      *
      * @access public
-     * @param mixed ѥ᡼ؿ
+     * @param object ǡ֥
+     * @param string URL
      */
-    function SyL_ActionForm($action='', $callback_parameter=null)
+    function SyL_ActionForm($action='')
     {
         parent::SyL_Form($this->name, $action);
-
-        if ($callback_parameter) {
-            $this->setCallbackParameter($callback_parameter);
-        }
-
-        if (is_array($this->form_config)) {
-            foreach ($this->form_config as $name => $values) {
-                $type         = $values['type'];
-                $display_name = isset($values['display_name']) ? $values['display_name'] : $name;
-                $options      = isset($values['options'])      ? $values['options']      : array();
-                $attributes   = isset($values['attributes'])   ? $values['attributes']   : array();
-                // Ǻ
-                $element =& $this->createElement($type, $name, $display_name, $options, $attributes);
-                if (isset($values['validate']) && (count($values['validate']) > 0)) {
-                    $vs =& SyL_Validators::create();
-                    foreach ($values['validate'] as $v_name => $v_values) {
-                        $v_parameters = isset($v_values['parameters']) ? $v_values['parameters'] : array();
-                        $vs->add(SyL_Validator::create($v_name, $v_values['message'], $v_parameters));
-                    }
-                    $element->setValidators($vs);
-                }
-                $this->addElement($element);
-            }
-        } else {
-            trigger_error("[SyL error] Invalid form config (" . var_export($this->form_config) . ")", E_USER_ERROR);
-        }
     }
 
     /**
      * ե᥽å
      *
+     * @static
      * @access public
      * @param string ե४֥̾
      * @param string URL
-     * @param mixed ѥ᡼ؿ
      * @return object ե४֥
      */
-    function &factory($formname, $action='', $callback_parameter=null)
+    function &factory($formpath, $action='')
     {
-        $formname = ucfirst($formname);
-        include_once SYL_PROJECT_LIB_DIR . "/forms/{$formname}.php";
-        $form =& new $formname($action, $callback_parameter);
+        SyL_Loader::lib($formpath);
+        $classname = SyL_Loader::convertClass($formpath);
+        $form =& new $classname($action);
         return $form;
     }
 
+    /**
+     * ǡ֥ȤΥХå᥽åɤϿ
+     *
+     * @access public
+     * @param object ǡ֥
+     */
+    function registerInput(&$data)
+    {
+        // ѥ᡼᥽åɥå
+        $this->setInputCallback(array(&$data, 'get'));
+    }
+
+    /**
+     * Ǥ°ɲä
+     *
+     * @access public
+     * @param string ̾
+     * @param array °
+     */
+    function addConfig($name, $attributes)
+    {
+        $this->form_config[$name] = $attributes;
+    }
+
+    /**
+     * եѥ᡼å
+     *
+     * @access public
+     * @param string ̾
+     * @param array եѥ᡼
+     */
+    function build()
+    {
+        foreach ($this->form_config as $name => $values) {
+            $type         = $values['type'];
+            $display_name = isset($values['display_name']) ? $values['display_name'] : $name;
+            $options      = isset($values['options'])      ? $values['options']      : array();
+            $attributes   = isset($values['attributes'])   ? $values['attributes']   : array();
+            // Ǻ
+            $element =& $this->createElement($type, $name, $display_name, $options, $attributes);
+            if (isset($values['validate']) && (count($values['validate']) > 0)) {
+                $vs =& SyL_Validators::create();
+                foreach ($values['validate'] as $v_name => $v_values) {
+                    $v_parameters = isset($v_values['parameters']) ? $v_values['parameters'] : array();
+                    $vs->add(SyL_Validator::create($v_name, $v_values['message'], $v_parameters));
+                }
+                $element->setValidators($vs);
+            }
+            $this->addElement($element);
+        }
+    }
 }
 
 ?>
