@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Auth.php,v 1.4 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Auth.php,v 1.5 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Auth.php,v 1.4 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Auth.php,v 1.5 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Auth
@@ -96,11 +96,11 @@ class SyL_Auth
      * 1ĤΥ󥹥󥹤λȤ롣
      *
      * ˡ
-     *   $SyL_Auth =& SyL_Auth::getInstance();
+     *   $SyL_Auth =& SyL_Auth::singleton();
      *
      * @access public
      */
-    function &getInstance()
+    function &singleton()
     {
         static $singleton;
         if (!is_object($singleton)) {
@@ -123,7 +123,7 @@ class SyL_Auth
         $classname = 'SyL_Auth' . ucfirst($type);
         include_once SYL_INCLUDE_DIR . "/framework/Auth/{$classname}.php";
         $obj = new $classname();
-        $request =& SyL_Request::getInstance();
+        $request =& SyL_Request::singleton();
         $obj->session =& $request->getSessionObject();
         return $obj;
     }
