@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.6 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.7 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -38,7 +38,6 @@
 require_once SYL_INCLUDE_DIR . '/framework/SyL_Router.php';
 /**
  * PHPեɥ饹
- *
  * ե졼ǤϻѤƤʤޤǥ¦Υإѥ饹
  */
 require_once SYL_INCLUDE_DIR . '/framework/SyL_Loader.php';
@@ -50,7 +49,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Loader.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.6 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.7 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Context
@@ -86,6 +85,13 @@ class SyL_Context
      * @var string
      */
     var $view_type = '';
+    /**
+     * ƥץ졼ȥե
+     * 
+     * @access private
+     * @var string
+     */
+    var $template_file = '';
     /**
      * 쥤̾
      * 
@@ -183,17 +189,6 @@ class SyL_Context
         return is_object($this->router) ? $this->router->getClassName() : null;
     }
 
-    /**
-     * PATH_INFO
-     *
-     * @access public
-     * @return array PATH_INFO
-     */
-    function getPathInfoArray()
-    {
-        return is_object($this->router) ? $this->router->getPathInfoArray() : null;
-    }
-
     /**
      * ӥ塼פ򥻥å
      *
@@ -216,6 +211,70 @@ class SyL_Context
         return $this->view_type;
     }
 
+    /**
+     * ƥץ졼ȥե򥻥å
+     * 
+     * @access public
+     * @param string ƥץ졼ȥե
+     */
+    function setTemplateFile($template_file)
+    {
+        $this->template_file = $template_file;
+    }
+
+    /**
+     * ƥץ졼ȥե򥻥åȡʥإѡ
+     * ǻ
+     * 
+     * @access public
+     * @param string ƥץ졼ȥե
+     */
+    function setTemplate($template)
+    {
+        $pos = strrpos($this->template_file, '.');
+        if ($pos === false) {
+            trigger_error("[SyL error] Template file extension not found ({$this->template_file})", E_USER_ERROR);
+        }
+        $ext = substr($this->template_file, $pos+1);
+        $this->template_file = SyL_Loader::convertPath($template, $ext);
+    }
+
+    /**
+     * ƥץ졼ȥǥ쥯ȥ
+     * 
+     * @access public
+     * @return string ƥץ졼ȥǥ쥯ȥ
+     */
+    function getTemplateDir()
+    {
+        return $this->controller->getTemplateDir() . '/';
+    }
+
+    /**
+     * ƥץ졼ȥե
+     * 
+     * @access public
+     * @return string ƥץ졼ȥե
+     */
+    function getTemplateFile()
+    {
+        $template_dir  = $this->getTemplateDir();
+        $template_file = $this->template_file;
+        if (preg_match('/^(\\\\|\/)(.+)$/', $template_file, $matches)) {
+            $template_file = $matches[2];
+        }
+
+        // ǥХå - ƥץ졼Ȥξ
+        SyL_Loggers::debug("[Context] Template info dir: {$template_dir} file: {$template_file}");
+
+        // ƥץ졼ȥե¸ߥå
+        if (!is_file($template_dir . $template_file)) {
+            SyL_Loggers::warn("[Context] Template file not found dir: {$template_dir} file: {$template_file}");
+            SyL_Response::redirect404();
+        }
+        return $template_file;
+    }
+
     /**
      * 쥤̾򥻥å
      *
@@ -273,28 +332,6 @@ class SyL_Context
         return $this->customized_view['file'];
     }
 
-    /**
-     * ե륿ͤ
-     * 
-     * @access public
-     * @param string ե륿̾
-     * @return mixed ե륿
-     */
-    function affectFilter($name)
-    {
-        // ե륿̾
-        $name = "__filter_{$name}";
-        // ե륿
-        $component =& $this->controller->container->getComponent($name);
-        if (!method_exists($component, $this->filter_method)) {
-            trigger_error("[SyL error] Undefined filter method ({$this->filter_method})", E_USER_ERROR);
-        }
-
-        $args = func_get_args();
-        array_shift($args);
-        return call_user_func_array(array(&$component, $this->filter_method), $args);
-    }
-
     /**
      * ݡͥȥ֥Ȥ򥻥å
      * 
