@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Loader.php,v 1.1 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Loader.php,v 1.2 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -35,11 +35,16 @@
 /**
  * PHPեɥ饹
  *
+ * SyL_DB.php
+ *   => SyL_Loader::lib('DB');
+ * DB/SyL_DBSqlBuilder.php
+ *   => SyL_Loader::lib('DB.SqlBuilder');
+ 
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Loader.php,v 1.1 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Loader.php,v 1.2 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Loader
@@ -54,19 +59,23 @@ class SyL_Loader
      */
     function lib($path)
     {
-        $path = call_user_func(array(__CLASS__, 'correctPath'), $path);
+        $classname = __CLASS__;
+
+        $tmp_path = call_user_func(array($classname, 'convertPath'), $path);
         // ץꥱ饤֥ǥ쥯ȥ
-        $base1 = SYL_PROJECT_LIB_DIR . $path;
+        $base1 = SYL_PROJECT_LIB_DIR . $tmp_path;
         if (is_file($base1)) {
-            return call_user_func(array(__CLASS__, 'load'), $base1);
-        }
-        // ɸ饤֥ǥ쥯ȥ
-        $base2 = SYL_INCLUDE_DIR . "/lib" . $path;
-        if (is_file($base2)) {
-            return call_user_func(array(__CLASS__, 'load'), $base2);
+            return call_user_func(array($classname, 'load'), $base1);
         }
 
-        trigger_error("[SyL error] file not found ({$base1} or {$base2})", E_USER_ERROR);
+        $tmp_path = call_user_func(array($classname, 'convertPathSyL'), $path);
+        // ɸ饤֥ǥ쥯ȥSyLѥѥ
+        $base2 = SYL_INCLUDE_DIR . "/lib" . $tmp_path;
+        if (is_file($base2)) {
+            return call_user_func(array($classname, 'load'), $base2);
+        }
+
+        trigger_error("[SyL error] Library file not found ({$base1} or {$base2})", E_USER_ERROR);
     }
 
     /**
@@ -79,13 +88,15 @@ class SyL_Loader
      */
     function fw($path)
     {
-        $path = call_user_func(array(__CLASS__, 'correctPath'), $path);
-        $base = SYL_INCLUDE_DIR . "/framework" . $path;
-        if (is_file($base)) {
-            return call_user_func(array(__CLASS__, 'load'), $base);
+        $classname = __CLASS__;
+
+        $tmp_path = call_user_func(array($classname, 'convertPathSyL'), $path);
+        $base1 = SYL_INCLUDE_DIR . "/framework" . $tmp_path;
+        if (is_file($base1)) {
+            return call_user_func(array($classname, 'load'), $base1);
         }
 
-        trigger_error("[SyL error] file not found ({$base})", E_USER_ERROR);
+        trigger_error("[SyL error] Framework file not found ({$base1})", E_USER_ERROR);
     }
 
     /**
@@ -106,16 +117,63 @@ class SyL_Loader
     }
 
     /**
-     * ѥ
+     * ѥѴ
      * 
      * @static
      * @access public
-     * @param string ɥե
-     * @return string ɥե
+     * @param string ѥ
+     * @return string Ѵѥ
      */
-    function correctPath($path)
+    function convertPath($path, $ext='php')
     {
-        return '/' . str_replace('.', '/', $path) . '.php';
+        return '/' . implode('/', array_map('ucfirst', explode('.', $path))) . '.' . $ext;
+    }
+
+    /**
+     * SyL饤֥Ѥ˥ѥѴ
+     * 
+     * @static
+     * @access public
+     * @param string ѥ
+     * @return string Ѵѥ
+     */
+    function convertPathSyL($path)
+    {
+        $path      = array_map('ucfirst', explode('.', $path));
+        $classname = 'SyL_' . implode('', $path);
+        array_pop($path); // ե
+        $path = implode('/', $path);
+        if ($path == '') {
+            return "/{$classname}.php";
+        } else {
+            return "/{$path}/{$classname}.php";
+        }
+    }
+
+    /**
+     * ѥ饯饹̾
+     * 
+     * @static
+     * @access public
+     * @param string ѥ
+     * @return string 饹̾
+     */
+    function convertClass($path)
+    {
+        return implode('', array_map('ucfirst', explode('.', $path)));
+    }
+
+    /**
+     * ѥSyL饤֥ꥯ饹̾
+     * 
+     * @static
+     * @access public
+     * @param string ѥ
+     * @return string 饹̾
+     */
+    function convertClassSyL($path)
+    {
+        return 'SyL_' . call_user_func(array(__CLASS__, 'convertClass'), $path);
     }
 }
 
