@@ -35,7 +35,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDao.php,v 1.1 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDao.php,v 1.2 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -52,7 +52,7 @@ require_once 'SyL_DBSqlTableConditions.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDao.php,v 1.1 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDao.php,v 1.2 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBDao
@@ -71,13 +71,41 @@ class SyL_DBDao
      * @var array
      */
     var $tables = array();
+    /**
+     * ڡ
+     *
+     * @access protected
+     * @var int
+     */
+    var $page = 0;
+    /**
+     * ڡ
+     *
+     * @access protected
+     * @var int
+     */
+    var $limit = 10;
+    /**
+     * ڡ饹
+     *
+     * @access protected
+     * @var object
+     */
+    var $pager = null;
     /**
      * SELECT
      *
      * @access private
      * @var array
      */
-    var $select_columns = array();
+    var $select_headers = array();
+    /**
+     * ORDER BY
+     *
+     * @access private
+     * @var array
+     */
+    var $sort_columns = array();
     /**
      * Ϣ³DML˥顼ȯ硢
      * ߤե饰
@@ -122,41 +150,95 @@ class SyL_DBDao
      * @access public
      * @return array SELECT
      */
-    function getSelectColumns()
+    function getSelectHeaders()
     {
-        return $this->select_columns;
+        return $this->select_headers;
+    }
+
+    /**
+     * ȹܤ
+     *
+     * @access public
+     * @return array ȹ
+     */
+    function getSortColumns()
+    {
+        return $this->sort_columns;
+    }
+
+    /**
+     * ڡɽѥ᡼򥻥å
+     *
+     * @access public
+     * @param int ɽڡ
+     * @param int 1ڡη
+     */
+    function setPage($page=1, $limit=20)
+    {
+        $this->page  = $page;
+        $this->limit = $limit;
+    }
+
+    /**
+     * ڡ֥Ȥ
+     *
+     * @access public
+     * @return object ڡ֥
+     */
+    function &getPager()
+    {
+        return $this->pager;
+    }
+
+    /**
+     * ץ饤ޥꥭ
+     *
+     * @access public
+     * @return object ڡ֥
+     */
+    function getPrimary($table)
+    {
+        // ѤѴ
+        $table = $this->arrangeTables($table);
+
+        $primary = array();
+        foreach(array_keys($table) as $name) {
+            $primary = array_merge($primary, $table[$name]->getPrimary());
+        }
+        return $primary;
     }
 
     /**
      * DBǡ
      *
      * @access public
-     * @param mixed ơ֥륪֥ 
-     * @param string ơ֥Υꥢ̾
-     * @return bool true: OK, false: 顼
+     * @param object or array ơ֥륪֥ 
+     * @return array ǡ
      */
-    function select($table, $alias='')
+    function select($table)
     {
         // ѤѴ
-        $table = $this->arrangeTables($table, $alias);
+        $table = $this->arrangeTables($table);
 
         $selects   = array();
         $froms     = array();
         $wheres    = array();
         $order_bys = array();
-        $this->select_columns = array();
+        $this->select_headers = array();
         foreach(array_keys($table) as $name) {
             $selects    = array_merge($selects, $table[$name]->getSelectColumns());
             $froms      = array_merge($froms, (array)$table[$name]->getSelectName());
             $conditions = $table[$name]->getConditions();
             $wheres[]   = ($conditions) ? $conditions->getWhere($this->conn) : '';
             $order_bys  = array_merge($order_bys, $table[$name]->getSorts());
-
-            $this->select_columns = array_merge($this->select_columns, $table[$name]->getSelectColumnNames());
+            // SELECTݻ
+            $this->select_headers = array_merge($this->select_headers, $table[$name]->getSelectHeaders());
         }
 
         $where    = implode(' AND ', $wheres);
         $order_by = implode(', ', $order_bys);
+        // ȥȥݻ
+        $this->sort_columns = str_replace(' ', '.', $order_bys);
 
         $sql  = "";
         $sql .= "SELECT ";
@@ -172,22 +254,27 @@ class SyL_DBDao
         $sql .=   $order_by . " ";
         }
 
-        return $this->conn->query($sql);
+        if ($this->page === 0) {
+            // ̾
+            return $this->conn->query($sql);
+        } else {
+            // ڡ󥰤
+            $this->conn->queryPageRef($sql, $result, $this->pager, $this->limit, $this->page);
+            return $result;
+        }
     }
 
-
     /**
      * DBϿ
      *
      * @access public
      * @param mixed ơ֥륪֥
-     * @param string ơ֥Υꥢ̾
      * @return bool true: OK, false: 顼
      */
-    function insert($table, $alias='')
+    function insert($table)
     {
         // ѤѴ
-        $table = $this->arrangeTables($table, $alias);
+        $table = $this->arrangeTables($table);
         // INSERT¹
         return $this->exec($table, 'insert');
     }
@@ -197,13 +284,12 @@ class SyL_DBDao
      *
      * @access public
      * @param mixed ơ֥륪֥
-     * @param string ơ֥Υꥢ̾
      * @return bool true: OK, false: 顼
      */
-    function update($table, $alias='')
+    function update($table)
     {
         // ѤѴ
-        $table = $this->arrangeTables($table, $alias);
+        $table = $this->arrangeTables($table);
         // UPDATE¹
         return $this->exec($table, 'update');
     }
@@ -213,13 +299,12 @@ class SyL_DBDao
      *
      * @access public
      * @param mixed ơ֥륪֥
-     * @param string ơ֥Υꥢ̾
      * @return bool true: OK, false: 顼
      */
-    function delete($table, $alias='')
+    function delete($table)
     {
         // ѤѴ
-        $table = $this->arrangeTables($table, $alias);
+        $table = $this->arrangeTables($table);
         // DELETE¹
         return $this->exec($table, 'delete');
     }
@@ -231,30 +316,16 @@ class SyL_DBDao
      * @param mixed ơ֥륪֥
      * @param string ơ֥Υꥢ̾
      */
-    function arrangeTables($table, $alias='')
+    function arrangeTables($table)
     {
         $result = array();
         // ơ֥륪֥Ȥξ
         if (is_object($table)) {
-            if ($alias) {
-                $table->setAliasName($alias);
-            } else {
-                $alias = $table->getName();
-            }
+            $alias = $table->getAliasName();
             $result[$alias] = $table;
         } else if (is_array($table)) {
-            if (isset($table[0])) {
-                if (is_array($table[0])) {
-                    foreach (array_keys($table) as $key) {
-                        $result += $this->arrangeTables($table[$key]);
-                    }
-                } else {
-                    if (isset($table[1])) {
-                        $result += $this->arrangeTables($table[0], $table[1]);
-                    } else {
-                        $result += $this->arrangeTables($table[0]);
-                    }
-                }
+            foreach ($table as $tmp) {
+                $result += $this->arrangeTables($tmp);
             }
         }
         return $result;
