@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.16 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.17 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.16 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.17 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DB
@@ -175,6 +175,7 @@ class SyL_DB
                 trigger_error("[SyL error] DSN(connection string) not found", E_USER_ERROR);
             }
         }
+
         static $singleton = array();
         if (!isset($singleton[$dsn]) || !is_object($singleton[$dsn])) {
             $tmp  = explode(':', $dsn, 2);
@@ -191,11 +192,11 @@ class SyL_DB
             if (!$dbtype) {
                 $dbtype = $type;
             }
-
-            $classname = 'SyL_DB' . $type;
+            // ɥ饤Х饹̾
+            $classname = 'SyL_DBDriver' . $type;
 
             // ¥󥹥󥹺
-            include_once dirname(__FILE__) . "/DB/{$classname}.php";
+            include_once dirname(__FILE__) . "/DB/Driver/{$classname}.php";
             $singleton[$dsn] = new $classname($dbtype);
             if ($server_encode) $singleton[$dsn]->server_encode = $server_encode;
             if ($client_encode) $singleton[$dsn]->client_encode = $client_encode;
