@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Form.php,v 1.12 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Form.php,v 1.13 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once 'SyL_Validation.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Form.php,v 1.12 2007/05/08 15:55:06 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Form.php,v 1.13 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Form
@@ -73,7 +73,7 @@ class SyL_Form
      * @access private
      * @var mixed
      */
-    var $callback_parameter = null;
+    var $input_callback = null;
     /**
      * ɽ
      *
@@ -143,7 +143,7 @@ class SyL_Form
         // եǽ
         $this->results['elements'] = array();
         // ǥեȤΥѥ᡼ؿ
-        $this->callback_parameter = array(&$this, 'getParameter');
+        $this->input_callback = array(&$this, 'getParameter');
     }
 
     /**
@@ -158,7 +158,8 @@ class SyL_Form
      */
     function &createElement($type, $element_name, $display_name, $options=array(), $attributes=array())
     {
-        $element =& SyL_FormElement::create($type, $element_name, $display_name, $this->getParameter($element_name), $options, $attributes);
+        $value = call_user_func($this->input_callback, $element_name);
+        $element =& SyL_FormElement::create($type, $element_name, $display_name, $value, $options, $attributes);
         if (is_a($element, 'SyL_FormElementGroup')) {
             $element->initGroup($this);
         }
@@ -215,12 +216,12 @@ class SyL_Form
      * @access public
      * @param mixed ѥ᡼ؿ
      */
-    function setCallbackParameter($callback_parameter)
+    function setInputCallback($callback)
     {
-        if (is_callable($callback_parameter)) {
-            $this->callback_parameter = $callback_parameter;
+        if (is_callable($callback)) {
+            $this->input_callback = $callback;
         } else {
-            trigger_error("[SyL error] Invalid callback parameter. Not function and method (" . var_export($callback_parameter) . ")", E_USER_ERROR);
+            trigger_error("[SyL error] Invalid callback parameter. Not function and method (" . var_export($input_callback) . ")", E_USER_ERROR);
         }
     }
 
