@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateAction.php,v 1.2 2007/06/05 13:08:24 seasonstream Exp $
+ * @version   CVS: $Id: CreateAction.php,v 1.3 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateAction.php,v 1.2 2007/06/05 13:08:24 seasonstream Exp $
+ * @version   CVS: $Id: CreateAction.php,v 1.3 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class CreateAction
@@ -54,7 +54,7 @@ class CreateAction
      */
     function trigger($project_dir, $app_name, $action_file)
     {
-        $action_dir = "{$project_dir}app/{$app_name}/actions";
+        $action_dir = "{$project_dir}app/{$app_name}/actions/";
         if (!is_dir($action_dir)) {
             echo "  creating directory {$action_dir}\n"; ob_flush();
             if (!mkdir($action_dir, 0755)) {
@@ -75,25 +75,19 @@ class CreateAction
         }
 
         for ($i=0; $i<count($action_file); $i++) {
-            if (!preg_match('/^(\\\\|\/)/', $action_file[$i])) {
-                $action_file[$i] = '/' . $action_file[$i];
-            }
-            $file = substr($action_file[$i], 1);
-            if (substr($file, -4) == '.php') {
-                $file = substr($file, 0, -4);
-            } else {
-                $action_file[$i] .= '.php';
+            if (preg_match('/^(\\\\|\/)/', $action_file[$i])) {
+                $action_file[$i] = '/' . substr($action_file[$i], 1);
             }
 
             // 饹̾Ѵ
-            $class_name = implode('_', array_map('ucfirst', preg_split('/(\\\\|\/)/', $file)));
+            $class_name = implode('_', array_map('ucfirst', preg_split('/(\\\\|\/)/', $action_file[$i])));
             $trans = array(
               '{SYL_CLASS}' => $class_name,
               '{APP_NAME}'  => $app_name
             );
             $contents_tmp = strtr($contents, $trans);
 
-            $file = $action_dir . $action_file[$i];
+            $file = $action_dir . ucfirst($action_file[$i]) . '.php';
             $tmp = dirname($file) . '/';
             $create_dir = array();
             while (preg_match('/^' . preg_quote($action_dir, '/') . '/', $tmp)) {
